
from django.test import TestCase
from kanban.models import bug_statuses, Bug, Milestone, Project


class MilestoneTestCase(TestCase):
    def setUp(self):
        p1 = Project.objects.create()
        p1.save()
        self.m1 = Milestone.objects.create(max_sp=4, sort_order=0, project=p1)
        self.m1.save()
        bug_sps = [1.0, 1.0, 2.0, 0.5]
        self.m1_total_sp = 4.5
        num = 1
        for sp in bug_sps:
            b = Bug.objects.create(number=num, milestone=self.m1, sp=sp)
            b.save()
            num += 1

    def testTotalSp(self):
        self.assertEqual(self.m1.total_sp, self.m1_total_sp)

    def testIsFull(self):
        self.m1.max_sp = self.m1_total_sp
        self.assertTrue(self.m1.is_full)

    def testIsFullWhileOver(self):
        self.m1.max_sp = self.m1_total_sp - 1.0
        self.assertTrue(self.m1.is_full)

    def testIsNotFull(self):
        self.m1.max_sp = self.m1_total_sp + 1.0
        self.assertFalse(self.m1.is_full)

    def testIsOverSpWhileOver(self):
        self.m1.max_sp = self.m1_total_sp - 1.0
        self.assertTrue(self.m1.is_over_sp)

    def testIsOverSpWhileAtMax(self):
        self.m1.max_sp = self.m1_total_sp
        self.assertFalse(self.m1.is_over_sp)

    def testIsNotOverSp(self):
        self.m1.max_sp = self.m1_total_sp + 1.0
        self.assertFalse(self.m1.is_over_sp)


class BugTestCase(TestCase):
    def setUp(self):
        p1 = Project.objects.create()
        p1.save()
        m1 = Milestone.objects.create(max_sp=4, sort_order=0, project=p1)
        m1.save()
        self.b1 = Bug.objects.create(number=1, milestone=m1, sp=1.0)

    def testBlocked(self):
        self.b1.status = "Incomplete"
        self.assertEqual(self.b1.status_class(), "blocked")

    def testNotBlocked(self):
        all_statuses = list(bug_statuses)
        all_statuses.remove("Incomplete")
        for status in all_statuses:
            self.b1.status = status
            self.assertEqual(self.b1.status_class(), "")
